@@ -4,8 +4,7 @@ use strict;
 use warnings;
 use Digest;
 use Encode qw( str2bytes );
-
-our $VERSION = '0.00001';
+use Crypt::URandom::Token qw( urandom_token );
 
 my %digest_lengths =
   (
@@ -49,7 +48,7 @@ sub make_encode_sub {
   my $encoder = sub {
     my ($plain_text, $salt) = @_;
     $plain_text = str2bytes($encode, $plain_text,  Encode::FB_PERLQQ | Encode::LEAVE_SRC) if $encode;
-    $salt ||= join('', map { $salt_pool[int(rand(65))] } 1 .. $slen);
+    $salt ||= $slen ? urandom_token($slen, \@salt_pool) : "";
     $object->reset()->add($plain_text.$salt);
     my $digest = $object->$format_method;
     #print "${plain_text}\t ${salt}:\t${digest}${salt}\n" if $salt;
